package com.miya.fastcashier.dialog;

import android.app.Dialog;
import android.content.Context;
import android.content.DialogInterface;
import android.text.TextUtils;
import android.view.Gravity;
import android.view.KeyEvent;
import android.view.View;
import android.view.Window;
import android.view.WindowManager;
import android.widget.ImageView;
import android.widget.TextView;

import androidx.constraintlayout.widget.Group;

import com.miya.fastcashier.R;
import com.miya.fastcashier.utils.ScanGunKeyEventHelper;


public class CodeScanDialog extends Dialog implements DialogInterface.OnDismissListener {

    private final ScanGunKeyEventHelper scanGunKeyEventHelper;
    private OnScanListener listener;

    public CodeScanDialog(Context context) {
        super(context);
        initWindow();
        setContentView(R.layout.dialog_code_scan);
        setCanceledOnTouchOutside(false);
        setOnDismissListener(this);
        scanGunKeyEventHelper = new ScanGunKeyEventHelper();
        scanGunKeyEventHelper.setOnBarCodeCatchListener(barcode -> {
            if (listener != null) {
                listener.onScan(barcode);
            }
        });
    }

    @Override
    public boolean dispatchKeyEvent(KeyEvent event) {
        scanGunKeyEventHelper.analysisKeyEvent(event);
        return true;
    }

    private void initWindow() {
        Window win = this.getWindow();
        win.getDecorView().setPadding(0, 0, 0, 0);
        WindowManager.LayoutParams lp = win.getAttributes();
        lp.width = WindowManager.LayoutParams.MATCH_PARENT;
        lp.height = WindowManager.LayoutParams.WRAP_CONTENT;
        lp.gravity = Gravity.BOTTOM;
        lp.windowAnimations = R.style.BottomInAndOutStyle;
        win.setAttributes(lp);
        win.setBackgroundDrawableResource(android.R.color.transparent);
    }

    public void setOnScanListener(OnScanListener listener) {
        this.listener = listener;
    }

    @Override
    public void onDismiss(DialogInterface dialogInterface) {
        if (scanGunKeyEventHelper != null) {
            scanGunKeyEventHelper.onDestroy();
        }
    }

    public interface OnScanListener {
        void onScan(String result);
    }
}
