package com.miya.fastcashier.viewmodel

import androidx.lifecycle.MutableLiveData
import androidx.lifecycle.ViewModel
import androidx.lifecycle.viewModelScope
import com.miya.fastcashier.beans.LoginRequest
import com.miya.fastcashier.beans.SelfCashierAccountInfo
import com.miya.fastcashier.net.BaseResult
import com.miya.fastcashier.service.LoginService
import kotlinx.coroutines.launch
import java.lang.RuntimeException

class LoginViewModel : ViewModel() {

    val loginLiveData: MutableLiveData<Result<SelfCashierAccountInfo>> = MutableLiveData()

    fun login(userName:String,passWord:String) {
        viewModelScope.launch {
            val result = try {
                Result.success(errorHandle(LoginService.getApi().login(LoginRequest(userName,passWord,""))))
            } catch (e: Exception) {
                Result.failure(e)
            }
            // 注意这里是主线程，直接用setValue()即可
            loginLiveData.value = result
        }
    }

    private fun <T> errorHandle(result: BaseResult<T>): T {
        if(result.code != "200"){
            throw RuntimeException(result.msg)
        }
        return result.data;
    }

}